# Demos

Here are some examples of applications you can build with Metanno.

<!-- --8<-- [start:demos] -->

=== card {: href=/demos/quaero-explorer/ }

    :fontawesome-solid-compass:
    **Quaero Explorer**

    ---
    Explore and edit the Quaero dataset.

<!-- --8<-- [end:demos] -->
